@@ -6,8 +6,6 @@
 #  An addon module for CMS Made Simple to allow users to create, manage
 #  and display products in a variety of ways.
 # 
-# Version: 1.1.5
-#
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
 # This project's homepage is: http://www.cmsmadesimple.org
@@ -59,7 +57,6 @@ define('PRODUCTS_PREF_DFLTSEARCH_TEMPLATE','products_pref_dfltsearch_template');
 
 class Products extends CGExtensions
 {
-  var $_product_cache;
   var $_hierarchy_cache;
   var $_category_cache;
   var $_admin_loaded;
@@ -68,7 +65,6 @@ class Products extends CGExtensions
   public function __construct()
   {
     parent::__construct();
-	$this->_product_cache = array();
 	$this->_hierarchy_cache = array();
 	$this->_category_cache = array();
 	$this->_admin_loaded = false;
@@ -78,6 +74,10 @@ class Products extends CGExtensions
     $smarty = cmsms()->GetSmarty();
 	$smarty->register_function('products_getcategory',
 							   array($this,'_smarty_products_getcategory'));
+	$smarty->register_function('products_hierarchy_breadcrumb',
+							   array($this,'_smarty_products_hierarchy_breadcrumb'));
+	$smarty->register_function('products_hierarchy_parent',
+							   array($this,'_smarty_products_hierarchy_parent'));
   }
 
   function GetName()
@@ -93,7 +93,8 @@ class Products extends CGExtensions
   function GetDependencies()
   {
 	return array('CGExtensions'=>'1.24',
-				 'CGSimpleSmarty'=>'1.4.4');
+				 'CGSimpleSmarty'=>'1.4.4',
+				 'JQueryTools'=>'1.0.11');
   }
 
   function AllowAutoInstall()
@@ -118,7 +119,7 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.17';
+	return '2.18.2';
   }
 
   function MinimumCMSVersion()
@@ -181,6 +182,8 @@ EOT;
 
 	$this->CreateParameter('hierarchytemplate','',$this->Lang('param_hierarchytemplate'));
 	$this->SetParameterType('hierarchytemplate',CLEAN_STRING);
+	$this->CreateParameter('hierarchypage','',$this->Lang('param_hierarchypage'));
+	$this->SetParameterType('hierarchypage',CLEAN_STRING);
 
 	$this->CreateParameter('sortby','product_name',$this->Lang('param_sortby'));
 	$this->SetParameterType('sortby',CLEAN_STRING);
@@ -194,6 +197,9 @@ EOT;
 	$this->CreateParameter('excludecat','',$this->Lang('param_excludecat'));
 	$this->SetParameterType('excludecat',CLEAN_STRING);
 
+	$this->CreateParameter('notpretty','',$this->Lang('param_notpretty'));
+	$this->SetParameterType('notpretty',CLEAN_STRING);
+	
 	$this->CreateParameter('category','',$this->Lang('param_category'));
 	$this->SetParameterType('category',CLEAN_STRING);
 	$this->SetParameterType('categoryname',CLEAN_STRING);
@@ -203,6 +209,8 @@ EOT;
 	$this->SetParameterType('pagelimit',CLEAN_INT);
 	$this->CreateParameter('parent','',$this->Lang('param_parent'));
 	$this->SetParameterType('parent',CLEAN_INT);
+	$this->CreateParameter('parents','',$this->Lang('param_parents'));
+	$this->SetParameterType('parents',CLEAN_STRING);
 	$this->CreateParameter('showall','',$this->Lang('param_showall'));
 	$this->SetParameterType('showall',CLEAN_INT);
 	$this->CreateParameter('field','',$this->Lang('param_field'));
@@ -277,15 +285,8 @@ EOT;
 						 array('action'=>'hierarchy','returnid'=>$hierpage));
   }
 
-  public function LazyLoadFrontend()
-  {
-	return FALSE;
-  }  
-
-  public function LazyLoadAdmin()
-  {
-	return TRUE;
-  }
+  public function LazyLoadFrontend() { return FALSE; }  
+  public function LazyLoadAdmin() { return TRUE; }
 
   function InstallPostMessage()
   {
@@ -304,7 +305,7 @@ EOT;
 
   function GetHelp($lang='en_US')
   {
-	return $this->Lang('help');
+	return file_get_contents(dirname(__FILE__).'/help.inc');
   }
 
   function GetAdminSection()
@@ -410,44 +411,8 @@ EOT;
   // deprecated
   function GetCategories($full = false)
   {
-	$gCms = cmsms();
-	$db = $gCms->GetDB();
-	$config = $gCms->GetConfig();
-		
-	if( count($this->_category_cache) )
-	  {
-		return $this->_category_cache;
-	  }
-
-	$entryarray = array();
-		
-	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_categories';
-    $query2 = 'SELECT * FROM '.cms_db_prefix().'module_products_category_fields 
-               WHERE category_id = ?';
-
-	$tmp = $db->GetArray($query);
-	foreach( $tmp as $row )
-	  {
-		$onerow = new stdClass();
-			
-		$onerow->id = $row['id'];
-		$onerow->name = $row['name'];
-		$onerow->value = false;
-		$onerow->file_location = $config['uploads_url'].'/'.$this->GetName().'/categories/'.$onerow->id;
-
-		if( $full )
-		  {
-			$tmp2 = $db->GetArray($query2,array($row['id']));
-			if( is_array($tmp2) && count($tmp2) > 0)
-			  {
-				$onerow->data = $tmp2;
-			  }
-		  }
-		$entryarray[] = $onerow;
-	  }
-
-	$this->_category_cache = $entryarray;
-	return $entryarray;
+	if( $full ) return product_utils::get_full_categories($full);
+	return product_utils::get_categories($full);
   }
 
 
@@ -507,52 +472,7 @@ EOT;
   // deprecated
   function GetFieldDefs($admin = false,$public = true)
   {
-	if( !is_array($this->_flddef_cache) )
-	  {
-		$entryarray = array();
-		$db = cmsms()->GetDB();
-		
-		if( $admin == true && $public == true )
-		  {
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
-		  }
-		else if( $public == true )
-		  {
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE public > 0 ORDER BY item_order';
-		  }
-		else
-		  {
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE admin_only <= 0 ORDER BY item_order';
-		  }
-		$dbresult = $db->GetArray($query);
-		
-		if( is_array($dbresult) )
-		  {
-			foreach( $dbresult as $row )
-			  {
-				$onerow = new stdClass();
-				
-				$onerow->id = $row['id'];
-				$onerow->name = $row['name'];
-				$onerow->prompt = $row['prompt'];
-				$onerow->type = $row['type'];
-				$tmp = explode("\n",$row['options']);
-				$tmp2 = array();
-				foreach( $tmp as $one )
-				  {
-					$one = trim($one);
-					$tmp2[$one] = $one;
-				  }
-				$onerow->options = $tmp2;
-				$onerow->max_length = $row['max_length'];
-				
-				$entryarray[] = $onerow;
-			  }
-		  }
-		$this->_flddef_cache = $entryarray;
-	  }
-		
-	return $this->_flddef_cache;
+	return product_utils::get_fielddefs($admin,$public);
   }
 
 
@@ -582,7 +502,8 @@ EOT;
 	$res = array();
 	foreach( $entryarray as $entry )
 	  {
-		$newentry = clone $entry;		
+		$newentry = clone $entry;
+		$newentry->value = null;
 		foreach ($dbresult as $row)
 		  {
 			if ($row['fielddef_id'] == $newentry->id)
@@ -622,16 +543,11 @@ EOT;
   {
 	// the product name, the description, and all data from
 	// text fields, textara fields, and dropdowns
-	if( !isset( $this->_product_cache[$product_id] ) )
-	  {
-		$this->GetProduct( $product_id );
-	  }
-
-	$results = array();
-	$product =& $this->_product_cache[$product_id];
+	$product = product_ops::get_product($product_id);
 	if( $product['status'] != 'published' ) return array();
 	$defs = $this->GetFieldDefsForProduct($product_id);
 
+	$results = array();
 	$results[] = $product['product_name'];
 	$results[] = $product['details'];
 	$results[] = $product['sku'];
@@ -658,19 +574,15 @@ EOT;
   // deprecated
   function GetProductNameFromId( $id )
   {
-	if( !isset( $this->_product_cache[$id] ) )
-	  {
-		$this->GetProduct( $id );
-	  }
-
-	return $this->_product_cache[$id]['product_name'];
+	$product = product_ops::get_product($id);
+	return $product['product_name'];
   }
 
 
   // depreacated
   function is_taxable($product_id)
   {
-    $tmp = $this->GetProduct($product_id);
+	$tmp = product_ops::get_product($product_id);
 	return $tmp['taxable'];
   }
 
@@ -685,18 +597,7 @@ EOT;
   // deprecated
   function GetProduct( $id )
   {
-	if( !isset($this->_product_cache[$id]) )
-	  {
-		$db = $this->GetDb();
-		$query = "SELECT p.*,ph.hierarchy_id AS hier_id FROM ".cms_db_prefix()."module_products p
-                  LEFT JOIN ".cms_db_prefix()."module_products_prodtohier ph ON p.id = ph.product_id
-                  WHERE p.id = ?";
-		$row = $db->GetRow( $query, array( $id ) );
-		if(!$row) return FALSE;
-		$this->_product_cache[$id] = $row;
-	  }
-
-	return $this->_product_cache[$id];
+	return product_ops::get_product($id);
   }
 
 
@@ -830,16 +731,23 @@ EOT;
   // deprecated, move to ops
   function BuildHierarchyList()
   {
-	$this->_load_admin();
-	return products_BuildHierarchyList($this);
+	$tmp = hierarchy_ops::get_flat_list(FALSE);
+	$list = array($this->Lang('none')=>-1);
+	if( is_array($tmp) && count($tmp) ) {
+	  foreach( $tmp as $one ) {
+		$list[$one['long_name']] = $one['id']; // backwards.
+	  }
+	}
+	return $list;
   }
 
 
   // deprecated, move to ops
   function CreateHierarchyDropdown($id,$name,$selectedvalue)
   {
-	$this->_load_admin();
-	return products_CreateHierarchyDropdown($this,$id,$name,$selectedvalue);
+	$tmp = $this->BuildHierarchyList();
+	$tmp = array_merge(array($this->Lang('any')=>''),$tmp);
+	return $this->CreateInputDropdown($id,$name,$tmp,-1,$selectedvalue);
   }
 
 
@@ -853,53 +761,47 @@ EOT;
 	$products = '';
 	$prettyurl = '';
 
- 	switch( $action )
-	  {
+	if( product_utils::can_do_pretty($action,$params) ) {
+	  switch( $action ) {
 	  case 'details':
 		$prettyurl = product_ops::pretty_url($params['productid'],$returnid,$params);
-	 	break;
+		break;
 
 	  case 'default':
-		if( isset($params['categoryid']) )
-		  {
-			// if the category id parameter is set, use bycategory
-			$prettyurl = sprintf("%s/bycategory/%d/%d",
-								 $this->GetPreference('urlprefix','products'),
-								 (int)$params['categoryid'],$returnid);
-			if( isset($params['categoryname']) )
-			  {
-				$prettyurl .= '/'.munge_string_to_url($params['categoryname']);
-			  }
+		if( isset($params['categoryid']) ) {
+		  // if the category id parameter is set, use bycategory
+		  $prettyurl = sprintf("%s/bycategory/%d/%d",
+							   $this->GetPreference('urlprefix','products'),
+							   (int)$params['categoryid'],$returnid);
+		  if( isset($params['categoryname']) ) {
+			$prettyurl .= '/'.munge_string_to_url($params['categoryname']);
 		  }
-		else if( isset($params['hierarchyid']) )
-		  {
-			// if the hierarchy id parameter is set, use byhierarchy
-			$prettyurl = sprintf("%s/byhierarchy/%d/%d",
-								 $this->GetPreference('urlprefix','products'),
-								 (int)$params['hierarchyid'],$returnid);
-		  }
-		else if( isset($params['fieldid']) )
-		  {
-			// no pretty urls for this atm.
-			$prettyurl = '';
-		  }
-		else
-		  {
-			// otherwise use summary
-			$prettyurl = sprintf("%s/summary/%d",
-								 $this->GetPreference('urlprefix','products'),
-								 $returnid);
-		  }
-	 	break;
+		}
+		else if( isset($params['hierarchyid']) ) {
+		  // if the hierarchy id parameter is set, use byhierarchy
+		  $prettyurl = sprintf("%s/byhierarchy/%d/%d",
+							   $this->GetPreference('urlprefix','products'),
+							   (int)$params['hierarchyid'],$returnid);
+		}
+		else if( isset($params['fieldid']) ) {
+		  // no pretty urls for this atm.
+		  $prettyurl = '';
+		}
+		else {
+		  // otherwise use summary
+		  $prettyurl = sprintf("%s/summary/%d",
+							   $this->GetPreference('urlprefix','products'),
+							   $returnid);
+		}
+		break;
 
 	  case 'categorylist':
 		{
-		  if( isset($params['categoryid']) && !isset($params['categorylistdtltemplate']) )
-			{
-			  $prettyurl = sprintf("%s/viewcategory/%s/%s",
-								   $this->GetPreference('urlprefix','products'),
-								   (int)$params['categoryid'],$returnid);
-			}
+		  if( isset($params['categoryid']) && !isset($params['categorylistdtltemplate']) ) {
+			$prettyurl = sprintf("%s/viewcategory/%s/%s",
+								 $this->GetPreference('urlprefix','products'),
+								 (int)$params['categoryid'],$returnid);
+		  }
 		}
 		break;
 
@@ -907,24 +809,24 @@ EOT;
 		$prettyurl = sprintf('%s/hierarchy/%d',
 							 $this->GetPreference('urlprefix','products'),
 							 (int)$params['parent']);
-		if( $this->GetPreference('hierpage',-1) == -1 )
-		  {
-			// use returnid in the link.
-			$prettyurl .= '/'.$returnid;
-		  }
-		if( $this->GetPreference('prettyhierurls',0) )
-		  {
-			// add the name to the url.
-			$info = hierarchy_ops::get_hierarchy_info($params['parent']);
-			if( is_array($info) )
-			  {
-				$prettyurl .= '/'.munge_string_to_url($info['name']);
-			  }
+		if( $this->GetPreference('hierpage',-1) == -1 ) {
+		  // use returnid in the link.
+		  $prettyurl .= '/'.$returnid;
+		}
+		if( $this->GetPreference('prettyhierurls',0) ) {
+		  // add the name to the url.
+		  $info = hierarchy_ops::get_hierarchy_info($params['parent']);
+		  if( is_array($info) ) {
+			{
+			  $prettyurl .= '/'.munge_string_to_url($info['name']);
+			}
 		  }
+		}
 		break;
+	  } // switch
+	}
 
-	  }
-
+	if( isset($params['returnid']) ) unset($params['returnid']);
 	$out = $this->CreateLink($id,$action,$returnid,$contents,$params,$warn_message,
 							 $onlyhref,$inline,$addtext,$targetcontentonly,$prettyurl);
 
@@ -999,6 +901,43 @@ EOT;
 	return $obj;
   }
 
+  function _smarty_products_hierarchy_breadcrumb($params,&$smarty)
+  {
+	if( !isset($params['hierarchyid']) ) return;
+	$returnid = $this->GetPreference('hierpage');
+	if( $returnid <= 0 ) $returnid = cms_utils::get_current_pageid();
+	if( isset($params['pageid']) ) {
+	  $tmp = $this->resolve_alias_or_id($params['pageid']);
+	  if( $tmp ) $returnid = $tmp;
+	}
+	$delim = ' &raquo ';
+	if( isset($params['delim']) ) {
+	  $delim = $params['delim'];
+	}
+
+	$hierid = (int)$params['hierarchyid'];
+	$bc = hierarchy_ops::get_breadcrumb('prod',$hierid,$returnid,$delim);
+
+	if( isset($params['assign']) ) {
+	  $smarty->assign($params['assign'],$bc);
+	  return;
+	}
+	return $bc;
+  }
+
+  function _smarty_products_hierarchy_parent($params,&$smarty)
+  {
+	if( !isset($params['hierarchyid']) ) return;
+	$hid = (int)$params['hierarchyid'];
+	$info = hierarchy_ops::get_hierarchy_info($hid);
+	if( !is_array($info) ) return;
+
+	if( isset($params['assign']) ) {
+	  $smarty->assign($params['assign'],$info['parent_id']);
+	  return;
+	}
+	return $info['parent_id'];
+  }
 
   function get_product_info($product_id)
   {
