@@ -7,7 +7,7 @@ $lang['add'] = 'Add';
 $lang['addcategory'] = 'Add A Category';
 $lang['addfielddef'] = 'Add A Field';
 $lang['adjustable'] = 'Adjustable';
-$lang['addproduct'] = 'Add A Product';
+$lang['addproduct'] = 'Add an Item';
 $lang['add_attrib_set'] = 'Add Attribute';
 $lang['add_category_field'] = 'Associate Field with Category: &quot;%s&quot;';
 $lang['add_hierarchy_item'] = 'Add Hierarchy Item';
@@ -27,7 +27,7 @@ $lang['all'] = 'All';
 $lang['allcategories'] = 'All Categories';
 $lang['any'] = 'Any';
 $lang['areyousure'] = 'Are You Sure?';
-$lang['areyousure_deleteproduct'] = 'Are you sure you really want to delete this product, and all of the accompanying information for it?';
+$lang['areyousure_deleteproduct'] = 'Are you sure you really want to delete this item, and all of the accompanying information for it?';
 $lang['ascending'] = 'Ascending';
 $lang['attribute_name'] = 'Attribute Name';
 $lang['automatic'] = 'Automatic';
@@ -46,11 +46,11 @@ $lang['categorylisttemplates'] = 'CategoryList Templates';
 $lang['categorylisttemplate_addedit'] = 'Add/Edit A CategoryList Template';
 $lang['centimeters'] = 'Centimeters';
 $lang['checkbox'] = 'Checkbox';
-$lang['confirm_copyattributes'] = 'Any existing attribute sets for this product will be removed. Are you sure you want to continue?';
-$lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any products that are using this node will be set to no hierarchy';
+$lang['confirm_copyattributes'] = 'Any existing attribute sets for this item will be removed. Are you sure you want to continue?';
+$lang['confirm_delete_hierarchy_node'] = 'Are you sure you want to delete this node?  Any items that are using this node will be set to no hierarchy';
 $lang['confirm_import'] = "Are you sure you really want to do this?\\n\\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.";
 $lang['copy'] = 'Copy';
-$lang['copy_product'] = 'Copy this product';
+$lang['copy_product'] = 'Copy this item';
 $lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category']  = 'Copy Category';
 $lang['createddate'] = 'Created Date';
@@ -88,6 +88,7 @@ $lang['edit_attributes'] = 'Edit Attributes';
 $lang['edit_category'] = 'Edit Category';
 $lang['edit_category_fields'] = 'Edit Category Fields for &quot;%s&quot;';
 $lang['edit_hierarchy_item'] = 'Edit Hierarchy Item';
+$lang['errors'] = 'Errors';
 $lang['error_attribset_exists'] = 'An attribute with that name already exists';
 $lang['error_dberror'] = 'Database error';
 $lang['error_duplicate_sku'] = 'Duplicate SKU value found';
@@ -106,16 +107,22 @@ $lang['error_onequantityfield'] = 'Only one quantity field is allowed';
 $lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
 $lang['error_permissiondenied'] = 'Permission Denied';
 $lang['error_product_aliasused'] = 'The alias specified is already in use';
-$lang['error_product_nameused'] = 'A product by that name already exists';
-$lang['error_product_notfound'] = 'The requested product could not be found';
-$lang['error_product_skuused'] = 'That SKU value is already in use by another product';
+$lang['error_product_nameused'] = 'An item by that name already exists';
+$lang['error_product_notfound'] = 'The requested item could not be found';
+$lang['error_product_skuused'] = 'That SKU value is already in use by another item';
 $lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
 $lang['error_sku_required'] = 'Please enter a unique SKU';
 $lang['error_upload_failed'] = 'Upload failed: %s';
-$lang['exclude_categories'] = 'Exclude products in the selected categories from the results';
+$lang['exclude_categories'] = 'Exclude items in the selected categories from the results';
 $lang['expire_six_months'] = 'After Six Months';
 $lang['expire_one_year'] = 'After One Year';
 $lang['expire_two_year'] = 'After Two Years';
+$lang['export_to_csv'] = 'Export to CSV';
+$lang['exportattribs'] = 'Export Attributes';
+$lang['exportcats'] = 'Export categories';
+$lang['exportdelim'] = 'Export field Delimiter';
+$lang['exportdraft'] = 'Export Draft Items';
+$lang['exportfields'] = 'Export Custom Fields';
 $lang['extra1'] = 'Extra Field 1';
 $lang['extra2'] = 'Extra Field 2';
 
@@ -125,6 +132,8 @@ $lang['fields'] = 'Fields';
 $lang['fielddef'] = 'Field Definition';
 $lang['fielddefs'] = 'Field Definitions';
 $lang['file'] = 'File';
+$lang['filter'] = 'Filter';
+$lang['filterinuse'] = 'in effect';
 $lang['filters'] = 'Filters';
 $lang['firstpage'] = '&lt;&lt;';
 
@@ -133,111 +142,6 @@ $lang['general_settings'] = 'General Settings';
 $lang['go'] = 'Go';
 
 # H
-$lang['help'] = <<<EOT
-<h3>What does this do?</h3>
-<p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is 'taxable' or not.</p>
-  <p>This module provides multiple custom field definitions, and for the ability to discriminate private from public data.</p>
-<h3>Features:</h3>
-<ul>
-  <li>Numerous Views</li>
-    <ul>
-      <li>Summary view</li>
-      <li>Category List View</li>
-      <li>Detail view</li> 
-      <li>Hierarchy Drill-down View</li>
-    </ul>
-  <li>Entirely Database Template Driven</li>
-  <p>Numerous templates of each type can be defined, defaults specified for each type, and the template used for each particular view can be specified as a parameter</p>
-  <li>Sorting and pagination in the summary view</li>
-  <li>Products can exist in multiple categories</li>
-  <li>Numerous custom fields can be defined, including images</li>
-  <li>Automatic thumbnail creation</li>
-  <li>Admin defined fields</li>
-  <li>Product attributes (including price adjustment)</li>
-  <li>Weight and taxable fields (for use in e-commerce solutions)</li>
-  <li>Products can have a status (published or draft) in order to hide products from public display at any time</li>
-  <li>Pretty URL Support</li>
-  <li><strong>More...</strong></li>
-</ul>
-
-<h3>How Do I Use It:</h3>
-<ul>
-<li>Set preferences</li>
-<p>Usually this is just a formality.  You should specify your default weight units, and your default currency symbol for your local environment.</p>
-<li>Setup users and permissions</li>
-<p>This module uses the 'Modify Templates' permission to allow users to be able to modify the various templates that can be used by this module.  As well, the 'Modify Site Preferences' permission is needed to be able to adjust the modules preferences.  In order to have the ability to modify field definitions, categories, or products, your users will need the 'Modify Products' permission.</p>
-<li>(optional) Define one or more categories</li>
-<p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the 'Categories' tab in the Product Managers admin section, and clicking 'Add A Category'.  From there you will be prompted for a category name.</p>
-<li>(optional) Define one or more custom fields</li>
-<p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
-<p>Currently a number of types of custom fields are available, including: 'textbox','checkbox',and 'textarea', 'dropdown', and 'file'.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
-<li>Create one or more products</li>
-<p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can also specify if the product is taxable.</p>
-<p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
-<p>If custom fields are defined, then input fields appropriate to the type of custom field will appear and allow you to specify data for each of them.  This data is optional.</p>
-<li>Add the appropriate tags into your page templates or page content</li>
-<p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
-<p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category='categoryname'}</code></p>
-</ul>
-<h3>Smarty Plugins</h3>
-<p>This module also registers one or more smarty plugins to aide in retrieving various products related information when designing products module templates:</p>
-<ul>
-  <li>{products_getcategory categoryid='99' [assign='tmp']}
-  <p>This plugin allows retrieving all of the information for a specific category id and optionally assigning it to the named smarty variable.  The returned is an object containing all of the information about a category, including its field values.<br/>i.e:. <code>{products_getcategory categoryid=1 assign='tmp'}Category name = {\$tmp->name}</code></p>
-   
-   </p>
-  </li>
-</ul>
-<h3>The <em>ajax_propval</em> Action</h3>
-  <p>The <em>ajax_propval</em> is a special action that is used to return the distinct values of a custom field, or a property via json.  Typically this action is used to perform autocomplete actions, and usually in conjunction with the search action.  This action accepts the parameters: field for the name of the field, and fieldval for indicating a starting value.  None of the parameters can be empty.  Below you will find a simple example of using the ajax_propval action to perform autocomplete for product names in conjunction with the search template.</p>
-<pre><code>&lt;script type="text/javascript"&gt;{literal}
-$(document).ready(function(){
-  var ajax_url = '{/literal}<span style="color: green;">{module_action_link module=Products action=ajax_propval urlonly=1 jsfriendly=1}</span>{literal}';
-  ajax_url = ajax_url + <span style="color: red;">'&showtemplate=false'</span>;
-
-  $(<span style="color: blue;">'#productname'</span>).autocomplete({
-    source: function(req,add){
-      var tmp =  ajax_url+<span style="color: red;">'&cntnt01field=::name::&cntnt01fieldval='</span>+req.term;
-      $.getJSON(tmp,function(json){
-        if( json.status == 'OK' && json.data.length > 0) {
-          add(json.data);
-        }
-      })
-    }    
-  });
-});
-{/literal}&lt;/script&gt;
-</code></pre>
-<p>As you can see from the above code snippet.. the {module_action_link} plugin from CGSimpleSmarty is used to generate a url that will trigger the ajax_propval action.  After that URL is retrieved, the showtemplate=false parameter is added to the URL.   When setting up the autocomplete plugin, the callback used to fill in the data values for the field uses ajax.  We take the ajax_url already prepared and add the field=::name:: and fieldval=req.term parameters to the URL.  The term is automatically provided by the autocomplete plugin in the req.term variiable.</p>
-<p>To use this example, the user would need to ensure that jquery is loaded, along with the jquery ui (including autocomplete), and any required stylesheets.  This could be done either in the page specific metadata field when editing the page containing the search form, or in the page template itself.</p>
-<h3>Support</h3>
-<p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
-<ul>
-<li>For the latest version of this module, FAQs or to file a bug report, please visit the cms made simple <a href="http://dev.cmsmadesimple.org">Developers Forge</a> and do a search for 'Products'</li>
-<li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
-<li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>
-<h3>Copyright and License</h3>
-<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&lt;calguy1000@cmsmadesimple.org&gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
-EOT;
 $lang['hierarchy']  = 'Hierarchy';
 $lang['hierarchy_position'] = 'Hierarchy Position';
 $lang['hierarchy_settings'] = 'Hierarchy Settings';
@@ -246,7 +150,7 @@ $lang['hierarchy_settings'] = 'Hierarchy Settings';
 $lang['id'] = 'Id';
 $lang['imagetext'] = 'Image';
 $lang['image_handling_settings'] = 'Image Handling Settings';
-$lang['import_from_csv'] = 'Import Products from CSV file';
+$lang['import_from_csv'] = 'Import items from CSV file';
 $lang['inches'] = 'Inches';
 $lang['include_children'] = 'Include Children?';
 $lang['info_alnumonly'] = 'Only alphanumeric characters. No whitespace, quotes, or non letter/number combinations';
@@ -254,15 +158,18 @@ $lang['info_attribtemplate'] = 'Possible variables are: {$attrib_text},{$attrib_
 $lang['info_attributes_copied'] = 'Attributes Copied';
 $lang['info_autowatermark'] = 'Watermark settings are taken from the CGExtensions Module';
 $lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
-$lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the product detail and summary displays';
-$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
-$lang['info_createfields'] = 'Create unknown product fields automatically? <em>(They will be created as text fields)</em>';
-$lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
-$lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
+$lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the item detail and summary displays';
+$lang['info_copy_attribsets'] = 'This action will copy Attribute Sets (excluding sku values) from another item.';
+$lang['info_clearattribs'] = 'Only applicable when updating existing items, this will clear all attribute information from the database for items before creating new ones';
+$lang['info_clearcategories'] = 'Only applicable when updating existing items, this will clear all category memberships befoe creating new ones';
+$lang['info_clearfields'] = 'Only applicable when updating existing items, this will clear all fields befoe creating field values';
+$lang['info_createfields'] = 'Create unknown item fields automatically? <em>(They will be created as text fields)</em>';
+$lang['info_createcategories'] = 'Automatically create item categories to match those of the CSV file, if it does not already exist';
+$lang['info_createhierarchy'] = 'Automatically create item hierarchies to match those of the CSV file if it does not already exist';
 $lang['info_decimal_units'] = 'This system understands (.) as the decimal point separator. i.e.: <strong>5.25</strong>';
 $lang['info_delimiter'] = 'Specify the character (or characters) that seperate each field';
-$lang['info_duplicateproducts'] = 'Specify how the system should handle a product whos name already exists in the CSV file';
-$lang['info_fielddefs_tab'] = '<strong>Note: </strong> All Fields defined here are available to all products.';
+$lang['info_duplicateproducts'] = 'Specify how the system should handle an item whos name already exists in the CSV file';
+$lang['info_fielddefs_tab'] = '<strong>Note: </strong> All Fields defined here are available to all items.';
 $lang['info_fieldproblems'] = 'Problems were encountered when dealing with one or more custom fields.  The action has completed successfully, however you should investigate and correct these problems';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
 $lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
@@ -271,10 +178,10 @@ $lang['info_imagestuff_deprecated'] = 'Image processing functions are deprecated
 $lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
 $lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Valid values are +-*#.##';
-$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
+$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if an item detail view is accessed directly by URL, and that item for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Public fields are available for the public to see';
 $lang['info_reorder_content'] = 'This operation allows dragging the individual nodes in the tree to adjust the order that they will be displayed in in the hierarchy view';
-$lang['info_setecomhandlers'] = 'This button will ensure that event handlers for ecommerce events are in place.  This is useful if asking the products module to keep track of a quantity on hand, but the event handlers did not get created during install or upgrade';
+$lang['info_setecomhandlers'] = 'This button will ensure that event handlers for ecommerce events are in place.  This is useful if asking the items module to keep track of a quantity on hand, but the event handlers did not get created during install or upgrade';
 
 # J
 # K
@@ -282,6 +189,7 @@ $lang['info_setecomhandlers'] = 'This button will ensure that event handlers for
 $lang['label'] = 'Label';
 $lang['label_skip'] = 'Skip';
 $lang['label_overwrite'] = 'Overwrite';
+$lang['label_update'] = 'Update';
 $lang['lastpage'] = '&gt;&gt;';
 $lang['last_modified'] = 'Last Modified';
 $lang['logotext'] = 'Second Image';
@@ -289,11 +197,11 @@ $lang['logotext'] = 'Second Image';
 # M
 $lang['maxlength'] = 'Maximum length <em>(applicable only on textbox fields)</em>';
 $lang['modifieddate'] = 'Modified Date';
-$lang['module_description'] = 'A module for managing a catalog of products, their price, images, etc, and for allowing users to build a cart';
+$lang['module_description'] = 'A module for managing a catalog of items, their price, images, etc, and for allowing users to build a cart';
 $lang['move_down'] = 'Move Down';
 $lang['move_up'] = 'Move Up';
 $lang['msg_eventhandlers_created'] = 'Event Handlers Created';
-$lang['msg_productcopied'] = 'Product successfully copied.  You are now editing the copy.  Any sku information in the product, and/or attributes has been cleared';
+$lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
 
 # N
 $lang['name'] = 'Name';
@@ -318,39 +226,41 @@ $lang['page_limit'] = 'Page Limit';
 $lang['param_action'] = <<<EOT
 Specify the behaviour of the module.  Possible values are:
 <ul>
-  <li>hierarchy -- Display a product list by hierarchy</li>
-  <li>categorylist - Display a list of product categories</li>
-  <li><em>default</em> - Display a summary of products</li>
-  <li>details - Display a detail view of a single product</li>
+  <li>hierarchy -- Display an item list by hierarchy</li>
+  <li>categorylist - Display a list of item categories</li>
+  <li><em>default</em> - Display a summary of items</li>
+  <li>details - Display a detail view of a single item</li>
   <li>fieldlist - Display a list of values from a specified field.
      <p>
 &nbsp;&nbsp;&nbsp;&nbsp;- This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &quot;color&quot; and then create a navigation based on the different colors.
      </p>
   </li>
-  <li>search - Display a form to allow searching products on various criterium</li>
+  <li>search - Display a form to allow searching items on various criterium</li>
 <li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
 </ul>
 EOT;
-$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified product categories.';
+$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories.';
 $lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist and fieldlist actions, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled.';
-$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
-$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the product name, sku and alias respectively.';
+$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding items that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the items that are in this category, but not in that category';
+$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively.';
 $lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &quot;::null::&quot; &quot;::notnull::&quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
-$lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=\'trucks*\'} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=\'*trucks\'} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=\'trucks,cars\'}';
+$lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=\'trucks*\'} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=\'*trucks\'} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=\'trucks,cars\'}';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
+$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> or search actions, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
-$lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what product to use for the display.';
+$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
+$lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what item to use for the display.';
 $lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
-$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
+$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without items) will be displayed.';
 $lang['param_sortorder'] = 'Specify the order of sorted fields in summary (including after a search) view.  Possible values are:
 <ul>
   <li><strong>asc</strong> -- Ascending order</li>
@@ -358,10 +268,10 @@ $lang['param_sortorder'] = 'Specify the order of sorted fields in summary (inclu
 </ul>';
 $lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
 <ul>
-  <li><strong>product_name</strong></li>
-  <li>id -- The product id</li>
-  <li>weight -- The product weight</li>
-  <li>price -- The product base price</li>
+  <li><strong>item_name</strong></li>
+  <li>id -- The item id</li>
+  <li>weight -- The item weight</li>
+  <li>price -- The item base price</li>
   <li>status -- Draft or published</li>
   <li>random -- Display in random order on each request</li>
   <li>created -- The creation date for this company record</li>
@@ -385,58 +295,62 @@ $lang['price'] = 'Price';
 $lang['price_adjustment'] = 'Price Adjustment';
 $lang['prefix_copyof'] = 'Copy Of';
 $lang['prevpage'] = '&lt;';
-$lang['product'] = 'Product';
-$lang['productname'] = 'Product Name';
-$lang['products'] = 'Products';
-$lang['product_detail_settings'] = 'Product Detail Settings';
-$lang['product_editing_settings'] = 'Product Editing Settings';
-$lang['product_summary_settings'] = 'Product Summary Settings';
-$lang['product_hierarchy'] = 'Product Hierarchy';
-$lang['product_info'] = 'Product Information';
+$lang['product'] = 'Item';
+$lang['productname'] = 'Item Name';
+$lang['products'] = 'Items';
+$lang['product_detail_settings'] = 'Item Detail Settings';
+$lang['product_editing_settings'] = 'Item Editing Settings';
+$lang['product_summary_settings'] = 'Item Summary Settings';
+$lang['product_hierarchy'] = 'Item Hierarchy';
+$lang['product_info'] = 'Item Information';
 $lang['product_manager'] = 'Product Manager';
 $lang['progress'] = 'Progress';
 $lang['prompt'] = 'Prompt';
 $lang['prompt_add_attribset'] = 'Add/Edit Attribute Set';
 $lang['prompt_allowed_filetypes'] = 'Allow upload of files with these extensions (for all upload fields)';
 $lang['prompt_allowed_imagetypes'] = 'Allow processing of images with these extensions (for image type fields)';
-$lang['prompt_attribtemplate'] = 'Template for display of product attribute values in dropdown';
+$lang['prompt_attribtemplate'] = 'Template for display of item attribute values in dropdown';
 $lang['prompt_autothumbnail'] = 'Automatically create thumbnails of images';
 $lang['prompt_autothumbnail_size'] = 'Maximum size (largest dimension) of the thumbnail.';
 $lang['prompt_autopreviewimg'] = 'Automatically create preview images of images';
 $lang['prompt_autopreviewimg_size'] = 'Maximum size (largest dimension) of the preview image.';
 $lang['prompt_autowatermark'] = 'Automatically place watermarks on images';
-$lang['prompt_applicable'] = 'Enable by default for all new products';
+$lang['prompt_applicable'] = 'Enable by default for all new items';
 $lang['prompt_batchsize'] = 'Batch Size';
 $lang['prompt_cart_module'] = 'Cart Module';
 $lang['prompt_cart_module_params'] = 'Cart Module Parameters';
+$lang['prompt_clearattribs'] = 'Clear attributes on update';
+$lang['prompt_clearcategories'] = 'Clear categories on update';
+$lang['prompt_clearfields'] = 'Clear fields on update';
 $lang['prompt_createcategories'] = 'Create Categories';
-$lang['prompt_createfields'] = 'Create Product Fields?';
-$lang['prompt_createhierarchy'] = 'Create Product Hierarchy';
+$lang['prompt_createfields'] = 'Create Item Fields?';
+$lang['prompt_createhierarchy'] = 'Create Item Hierarchy';
 $lang['prompt_csvfile'] = 'Upload CSV File';
 $lang['prompt_currencycode'] = 'Currency Code';
 $lang['prompt_currencysymbol'] = 'Currency Symbol';
-$lang['prompt_default_status'] = 'By default all new products have this status';
-$lang['prompt_default_taxable'] = 'By default all new products are taxable';
-$lang['prompt_deleteproductfiles'] = 'Delete any files associated with the product when the product is deleted?';
+$lang['prompt_default_status'] = 'By default all new items have this status';
+$lang['prompt_default_taxable'] = 'By default all new items are taxable';
+$lang['prompt_deleteproductfiles'] = 'Delete any files associated with the item when the item is deleted?';
 $lang['prompt_delimiter'] = 'Field Delimiter';
 $lang['prompt_detailpage'] = 'Default Detail Page';
 $lang['prompt_detailsfor'] = 'Details for %s';
-$lang['prompt_duplicateproducts'] = 'How to handle duplicate products?';
+$lang['prompt_duplicateproducts'] = 'How to handle duplicate items?';
 $lang['prompt_false'] = 'False';
 $lang['prompt_handleimages'] = 'Handle images?';
 $lang['prompt_imagepath'] = 'Image Path';
 $lang['prompt_lengthunits'] = 'Length Units';
-$lang['prompt_notfound_behavior'] = 'What action should be taken when a product cannot be displayed?';
+$lang['prompt_notfound_behavior'] = 'What action should be taken when an item cannot be displayed?';
 $lang['prompt_notfound_404'] = 'Generate a 404 error';
 $lang['prompt_notfound_301'] = 'Generate a 301 redirect';
 $lang['prompt_notfound_errormsg'] = 'Display an error message';
-$lang['prompt_notfound_msg'] = 'Error message for when a product cannot be found';
+$lang['prompt_notfound_msg'] = 'Error message for when an item cannot be found';
 $lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
 $lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
 $lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
-$lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
-$lang['prompt_products_matching'] = 'Products matching %s';
-$lang['prompt_sku_required'] = 'SKU is required for all products and attributes';
+$lang['prompt_prod_detailpage'] = 'Default Page for Item Detail Views';
+$lang['prompt_products_matching'] = 'Items matching %s';
+$lang['prompt_sku_required'] = 'SKU is required for all items and attributes';
+$lang['prompt_summary_newdefault'] = 'Use new summary view';
 $lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
 $lang['prompt_summarysortorder'] = 'Default Sort Order in summary mode';
 $lang['prompt_summarysorting'] = 'Default Sort Field in summary mode';
@@ -444,7 +358,7 @@ $lang['prompt_template'] = 'Template Source';
 $lang['prompt_true'] = 'True';
 $lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
 $lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
-$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
+$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Item Detail URLS';
 $lang['prompt_weightunits'] = 'Weight Units';
 $lang['public'] = 'Is this a public field?';
 $lang['published'] = 'Published';
@@ -455,6 +369,7 @@ $lang['quantity_on_hand'] = 'Quantity on Hand';
 # R
 $lang['random'] = 'Random';
 $lang['reorder_hierarchy'] = 'Reorder Hierarchy';
+$lang['reset'] = 'Reset';
 $lang['resettofactory'] = 'Reset to Factory Values';
 $lang['return'] = 'Return';
 $lang['return_to_top'] = 'Return to the top of the view';
